#############
Blueprint API
#############

The ``Blueprint`` class does not have any methods of its own to document.
You can train a new model using an existing blueprint by using the methods
of the ``Model`` class or of the ``Project`` class.

.. autoclass:: datarobot.models.Blueprint
   :members:
